@@ -75,7 +75,7 @@
 //! [Metadata Service]: https://cloud.google.com/compute/docs/metadata/overview
 
 use crate::credentials::dynamic::CredentialsProvider;
-use crate::credentials::{CacheableResource, Credentials, DEFAULT_UNIVERSE_DOMAIN};
+use crate::credentials::{CacheableResource, Credentials};
 use crate::errors::CredentialsError;
 use crate::headers_util::build_cacheable_headers;
 use crate::retry::{Builder as RetryTokenProviderBuilder, TokenProviderWithRetry};
@@ -114,7 +114,6 @@ where
     T: CachedTokenProvider,
 {
     quota_project_id: Option<String>,
-    universe_domain: Option<String>,
     token_provider: T,
 }
 
@@ -134,7 +133,6 @@ pub struct Builder {
     endpoint: Option<String>,
     quota_project_id: Option<String>,
     scopes: Option<Vec<String>>,
-    universe_domain: Option<String>,
     created_by_adc: bool,
     retry_builder: RetryTokenProviderBuilder,
 }
@@ -172,17 +170,6 @@ impl Builder {
         self
     }
 
-    /// Sets the universe domain for this credentials.
-    ///
-    /// Client libraries use `universe_domain` to determine
-    /// the API endpoints to use for making requests.
-    /// If not set, then credentials use `${service}.googleapis.com`,
-    /// otherwise they use `${service}.${universe_domain}.
-    pub fn with_universe_domain<S: Into<String>>(mut self, universe_domain: S) -> Self {
-        self.universe_domain = Some(universe_domain.into());
-        self
-    }
-
     /// Sets the [scopes] for this credentials.
     ///
     /// Metadata server issues tokens based on the requested scopes.
@@ -304,7 +291,6 @@ impl Builder {
     pub fn build(self) -> BuildResult<Credentials> {
         let mdsc = MDSCredentials {
             quota_project_id: self.quota_project_id.clone(),
-            universe_domain: self.universe_domain.clone(),
             token_provider: TokenCache::new(self.build_token_provider()),
         };
         Ok(Credentials {
@@ -322,13 +308,6 @@ where
         let cached_token = self.token_provider.token(extensions).await?;
         build_cacheable_headers(&cached_token, &self.quota_project_id)
     }
-
-    async fn universe_domain(&self) -> Option<String> {
-        if self.universe_domain.is_some() {
-            return self.universe_domain.clone();
-        }
-        return Some(DEFAULT_UNIVERSE_DOMAIN.to_string());
-    }
 }
 
 #[derive(Clone, Debug, PartialEq, serde::Deserialize, serde::Serialize)]
@@ -418,9 +397,199 @@ impl TokenProvider for MDSAccessTokenProvider {
     }
 }
 
+#[allow(dead_code)]
+pub(crate) mod idtoken {
+    //! Types for fetching ID tokens from the metadata service.
+    use std::sync::Arc;
+
+    use super::{
+        GCE_METADATA_HOST_ENV_VAR, MDS_DEFAULT_URI, METADATA_FLAVOR, METADATA_FLAVOR_VALUE,
+        METADATA_ROOT,
+    };
+    use crate::Result;
+    use crate::errors::CredentialsError;
+    use crate::token::{Token, TokenProvider};
+    use crate::{
+        BuildResult,
+        credentials::idtoken::{IDTokenCredentials, dynamic::IDTokenCredentialsProvider},
+    };
+    use async_trait::async_trait;
+    use http::HeaderValue;
+    use reqwest::Client;
+
+    #[derive(Debug)]
+    pub(crate) struct MDSCredentials<T>
+    where
+        T: TokenProvider,
+    {
+        token_provider: T,
+    }
+
+    #[async_trait]
+    impl<T> IDTokenCredentialsProvider for MDSCredentials<T>
+    where
+        T: TokenProvider,
+    {
+        async fn id_token(&self) -> Result<Token> {
+            self.token_provider.token().await
+        }
+    }
+
+    /// Creates [`IDTokenCredentials`] instances that fetch ID tokens from the
+    /// metadata service.
+    #[derive(Debug, Default)]
+    pub struct Builder {
+        endpoint: Option<String>,
+        format: Option<String>,
+        licenses: Option<String>,
+        target_audience: String,
+    }
+
+    impl Builder {
+        /// Creates a new `Builder`.
+        ///
+        /// The `target_audience` is a required parameter that specifies the
+        /// intended audience of the ID token. This is typically the URL of the
+        /// service that will be receiving the token.
+        pub fn new<S: Into<String>>(target_audience: S) -> Self {
+            Builder {
+                format: None,
+                endpoint: None,
+                licenses: None,
+                target_audience: target_audience.into(),
+            }
+        }
+
+        /// Sets the endpoint for this credentials.
+        ///
+        /// A trailing slash is significant, so specify the base URL without a trailing  
+        /// slash. If not set, the credentials use `http://metadata.google.internal`.
+        pub fn with_endpoint<S: Into<String>>(mut self, endpoint: S) -> Self {
+            self.endpoint = Some(endpoint.into());
+            self
+        }
+
+        /// Sets the [format] of the token.
+        ///
+        /// Specifies whether or not the project and instance details are included in the payload.
+        /// Specify `full` to include this information in the payload or `standard` to omit the information
+        /// from the payload. The default value is `standard``.
+        ///
+        /// [format]: https://cloud.google.com/compute/docs/instances/verifying-instance-identity#token_format
+        pub fn with_format<S: Into<String>>(mut self, format: S) -> Self {
+            self.format = Some(format.into());
+            self
+        }
+
+        /// Whether to include the [license codes] of the instance in the token.
+        ///
+        /// Specify `true` to include this information or `false` to omit this information from the payload.
+        /// The default value is `false`. Has no effect unless format is `full`.
+        ///
+        /// [license codes]: https://cloud.google.com/compute/docs/reference/rest/v1/images/get#body.Image.FIELDS.license_code
+        pub fn with_licenses(mut self, licenses: bool) -> Self {
+            self.licenses = if licenses {
+                Some("TRUE".to_string())
+            } else {
+                Some("FALSE".to_string())
+            };
+            self
+        }
+
+        fn build_token_provider(self) -> MDSTokenProvider {
+            let final_endpoint: String;
+
+            // Determine the endpoint and whether it was overridden
+            if let Ok(host_from_env) = std::env::var(GCE_METADATA_HOST_ENV_VAR) {
+                // Check GCE_METADATA_HOST environment variable first
+                final_endpoint = format!("http://{host_from_env}");
+            } else if let Some(builder_endpoint) = self.endpoint {
+                // Else, check if an endpoint was provided to the mds::Builder
+                final_endpoint = builder_endpoint;
+            } else {
+                // Else, use the default metadata root
+                final_endpoint = METADATA_ROOT.to_string();
+            };
+
+            MDSTokenProvider {
+                format: self.format,
+                licenses: self.licenses,
+                endpoint: final_endpoint,
+                target_audience: self.target_audience,
+            }
+        }
+
+        /// Returns an [`IDTokenCredentials`] instance with the configured
+        /// settings.
+        pub fn build(self) -> BuildResult<IDTokenCredentials> {
+            let creds = MDSCredentials {
+                token_provider: self.build_token_provider(),
+            };
+            Ok(IDTokenCredentials {
+                inner: Arc::new(creds),
+            })
+        }
+    }
+
+    #[derive(Debug, Clone, Default)]
+    struct MDSTokenProvider {
+        endpoint: String,
+        format: Option<String>,
+        licenses: Option<String>,
+        target_audience: String,
+    }
+
+    #[async_trait]
+    impl TokenProvider for MDSTokenProvider {
+        async fn token(&self) -> Result<Token> {
+            let client = Client::new();
+            let audience = self.target_audience.clone();
+            let request = client
+                .get(format!("{}{}/identity", self.endpoint, MDS_DEFAULT_URI))
+                .header(
+                    METADATA_FLAVOR,
+                    HeaderValue::from_static(METADATA_FLAVOR_VALUE),
+                )
+                .query(&[("audience", audience)]);
+            let request = self.format.iter().fold(request, |builder, format| {
+                builder.query(&[("format", format)])
+            });
+            let request = self.licenses.iter().fold(request, |builder, licenses| {
+                builder.query(&[("licenses", licenses)])
+            });
+
+            let response = request
+                .send()
+                .await
+                .map_err(|e| crate::errors::from_http_error(e, "failed to fetch token"))?;
+
+            if !response.status().is_success() {
+                let err =
+                    crate::errors::from_http_response(response, "failed to fetch token").await;
+                return Err(err);
+            }
+
+            let token = response
+                .text()
+                .await
+                .map_err(|e| CredentialsError::from_source(!e.is_decode(), e))?;
+
+            Ok(Token {
+                token,
+                token_type: "Bearer".to_string(),
+                // ID tokens from MDS do not have an expiry.
+                expires_at: None,
+                metadata: None,
+            })
+        }
+    }
+}
+
 #[cfg(test)]
 mod tests {
+    use super::idtoken;
     use super::*;
+    use crate::credentials::DEFAULT_UNIVERSE_DOMAIN;
     use crate::credentials::QUOTA_PROJECT_KEY;
     use crate::credentials::tests::{
         find_source_error, get_headers_from_cache, get_mock_auth_retry_policy,
@@ -550,7 +719,6 @@ mod tests {
 
         let mdsc = MDSCredentials {
             quota_project_id: None,
-            universe_domain: None,
             token_provider: TokenCache::new(mock),
         };
 
@@ -585,7 +753,6 @@ mod tests {
 
         let mdsc = MDSCredentials {
             quota_project_id: None,
-            universe_domain: None,
             token_provider: TokenCache::new(mock),
         };
         assert!(mdsc.headers(Extensions::new()).await.is_err());
@@ -987,16 +1154,84 @@ mod tests {
     }
 
     #[tokio::test]
-    async fn get_custom_universe_domain_success() -> TestResult {
-        let universe_domain = "test-universe";
-        let universe_domain_response = Builder::default()
-            .with_universe_domain(universe_domain)
-            .build()?
-            .universe_domain()
-            .await
-            .unwrap();
-        assert_eq!(universe_domain_response, universe_domain);
+    #[parallel]
+    async fn test_idtoken_builder_build() -> TestResult {
+        let server = Server::run();
+        let audience = "test-audience";
+        let format = "format";
+        let token_string = "test-id-token";
+        server.expect(
+            Expectation::matching(all_of![
+                request::path(format!("{MDS_DEFAULT_URI}/identity")),
+                request::query(url_decoded(contains(("audience", audience)))),
+                request::query(url_decoded(contains(("format", format)))),
+                request::query(url_decoded(contains(("licenses", "TRUE"))))
+            ])
+            .respond_with(status_code(200).body(token_string)),
+        );
 
+        let creds = idtoken::Builder::new(audience)
+            .with_endpoint(format!("http://{}", server.addr()))
+            .with_format(format)
+            .with_licenses(true)
+            .build()?;
+
+        let token = creds.id_token().await?;
+        assert_eq!(token.token, token_string);
+        assert_eq!(token.token_type, "Bearer");
+        assert!(token.expires_at.is_none());
+        Ok(())
+    }
+
+    #[tokio::test]
+    #[serial]
+    async fn test_idtoken_builder_build_with_env_var() -> TestResult {
+        let server = Server::run();
+        let audience = "test-audience";
+        let token_string = "test-id-token";
+        server.expect(
+            Expectation::matching(all_of![
+                request::path(format!("{MDS_DEFAULT_URI}/identity")),
+                request::query(url_decoded(contains(("audience", audience))))
+            ])
+            .respond_with(status_code(200).body(token_string)),
+        );
+
+        let addr = server.addr().to_string();
+        let _e = ScopedEnv::set(super::GCE_METADATA_HOST_ENV_VAR, &addr);
+
+        let creds = idtoken::Builder::new(audience).build()?;
+
+        let token = creds.id_token().await?;
+        assert_eq!(token.token, token_string);
+
+        let _e = ScopedEnv::remove(super::GCE_METADATA_HOST_ENV_VAR);
+        Ok(())
+    }
+
+    #[tokio::test]
+    #[parallel]
+    async fn test_idtoken_provider_http_error() -> TestResult {
+        let server = Server::run();
+        let audience = "test-audience";
+        server.expect(
+            Expectation::matching(all_of![
+                request::path(format!("{MDS_DEFAULT_URI}/identity")),
+                request::query(url_decoded(contains(("audience", audience))))
+            ])
+            .respond_with(status_code(503)),
+        );
+
+        let creds = idtoken::Builder::new(audience)
+            .with_endpoint(format!("http://{}", server.addr()))
+            .build()?;
+
+        let err = creds.id_token().await.unwrap_err();
+        let source = find_source_error::<reqwest::Error>(&err);
+        assert!(
+            matches!(source, Some(e) if e.status() == Some(StatusCode::SERVICE_UNAVAILABLE)),
+            "{err:?}"
+        );
         Ok(())
     }
 }
