@@ -129,6 +129,7 @@ macro_rules! impl_display {
 
 /// Representation of JSON Patch (list of patch operations)
 #[derive(Clone, Debug, Default, Deserialize, Eq, PartialEq, Serialize)]
+#[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
 #[cfg_attr(feature = "utoipa", derive(utoipa::ToSchema))]
 pub struct Patch(pub Vec<PatchOperation>);
 
@@ -144,10 +145,12 @@ impl std::ops::Deref for Patch {
 
 /// JSON Patch 'add' operation representation
 #[derive(Clone, Debug, Default, Deserialize, Eq, PartialEq, Serialize)]
+#[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
 #[cfg_attr(feature = "utoipa", derive(utoipa::ToSchema))]
 pub struct AddOperation {
     /// JSON-Pointer value [RFC6901](https://tools.ietf.org/html/rfc6901) that references a location
     /// within the target document where the operation is performed.
+    #[cfg_attr(feature = "schemars", schemars(schema_with = "String::json_schema"))]
     #[cfg_attr(feature = "utoipa", schema(value_type = String))]
     pub path: PointerBuf,
     /// Value to add to the target location.
@@ -158,10 +161,12 @@ impl_display!(AddOperation);
 
 /// JSON Patch 'remove' operation representation
 #[derive(Clone, Debug, Default, Deserialize, Eq, PartialEq, Serialize)]
+#[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
 #[cfg_attr(feature = "utoipa", derive(utoipa::ToSchema))]
 pub struct RemoveOperation {
     /// JSON-Pointer value [RFC6901](https://tools.ietf.org/html/rfc6901) that references a location
     /// within the target document where the operation is performed.
+    #[cfg_attr(feature = "schemars", schemars(schema_with = "String::json_schema"))]
     #[cfg_attr(feature = "utoipa", schema(value_type = String))]
     pub path: PointerBuf,
 }
@@ -170,10 +175,12 @@ impl_display!(RemoveOperation);
 
 /// JSON Patch 'replace' operation representation
 #[derive(Clone, Debug, Default, Deserialize, Eq, PartialEq, Serialize)]
+#[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
 #[cfg_attr(feature = "utoipa", derive(utoipa::ToSchema))]
 pub struct ReplaceOperation {
     /// JSON-Pointer value [RFC6901](https://tools.ietf.org/html/rfc6901) that references a location
     /// within the target document where the operation is performed.
+    #[cfg_attr(feature = "schemars", schemars(schema_with = "String::json_schema"))]
     #[cfg_attr(feature = "utoipa", schema(value_type = String))]
     pub path: PointerBuf,
     /// Value to replace with.
@@ -184,14 +191,17 @@ impl_display!(ReplaceOperation);
 
 /// JSON Patch 'move' operation representation
 #[derive(Clone, Debug, Default, Deserialize, Eq, PartialEq, Serialize)]
+#[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
 #[cfg_attr(feature = "utoipa", derive(utoipa::ToSchema))]
 pub struct MoveOperation {
     /// JSON-Pointer value [RFC6901](https://tools.ietf.org/html/rfc6901) that references a location
     /// to move value from.
+    #[cfg_attr(feature = "schemars", schemars(schema_with = "String::json_schema"))]
     #[cfg_attr(feature = "utoipa", schema(value_type = String))]
     pub from: PointerBuf,
     /// JSON-Pointer value [RFC6901](https://tools.ietf.org/html/rfc6901) that references a location
     /// within the target document where the operation is performed.
+    #[cfg_attr(feature = "schemars", schemars(schema_with = "String::json_schema"))]
     #[cfg_attr(feature = "utoipa", schema(value_type = String))]
     pub path: PointerBuf,
 }
@@ -200,14 +210,17 @@ impl_display!(MoveOperation);
 
 /// JSON Patch 'copy' operation representation
 #[derive(Clone, Debug, Default, Deserialize, Eq, PartialEq, Serialize)]
+#[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
 #[cfg_attr(feature = "utoipa", derive(utoipa::ToSchema))]
 pub struct CopyOperation {
     /// JSON-Pointer value [RFC6901](https://tools.ietf.org/html/rfc6901) that references a location
     /// to copy value from.
+    #[cfg_attr(feature = "schemars", schemars(schema_with = "String::json_schema"))]
     #[cfg_attr(feature = "utoipa", schema(value_type = String))]
     pub from: PointerBuf,
     /// JSON-Pointer value [RFC6901](https://tools.ietf.org/html/rfc6901) that references a location
     /// within the target document where the operation is performed.
+    #[cfg_attr(feature = "schemars", schemars(schema_with = "String::json_schema"))]
     #[cfg_attr(feature = "utoipa", schema(value_type = String))]
     pub path: PointerBuf,
 }
@@ -216,10 +229,12 @@ impl_display!(CopyOperation);
 
 /// JSON Patch 'test' operation representation
 #[derive(Clone, Debug, Default, Deserialize, Eq, PartialEq, Serialize)]
+#[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
 #[cfg_attr(feature = "utoipa", derive(utoipa::ToSchema))]
 pub struct TestOperation {
     /// JSON-Pointer value [RFC6901](https://tools.ietf.org/html/rfc6901) that references a location
     /// within the target document where the operation is performed.
+    #[cfg_attr(feature = "schemars", schemars(schema_with = "String::json_schema"))]
     #[cfg_attr(feature = "utoipa", schema(value_type = String))]
     pub path: PointerBuf,
     /// Value to test against.
@@ -230,6 +245,7 @@ impl_display!(TestOperation);
 
 /// JSON Patch single patch operation
 #[derive(Debug, Serialize, Deserialize, Clone, PartialEq, Eq)]
+#[cfg_attr(feature = "schemars", derive(schemars::JsonSchema))]
 #[cfg_attr(feature = "utoipa", derive(utoipa::ToSchema))]
 #[serde(tag = "op")]
 #[serde(rename_all = "lowercase")]
