@@ -22,10 +22,12 @@ pub mod version_spec;
 pub mod compression_level;
 mod environment_yaml;
 mod generic_virtual_package;
+pub mod minimal_prefix_record;
 pub mod package;
 mod package_name;
 pub mod prefix;
 pub mod prefix_record;
+mod record_traits;
 
 #[cfg(test)]
 use std::path::{Path, PathBuf};
@@ -44,11 +46,15 @@ pub use match_spec::{
     parse::ParseMatchSpecError,
     MatchSpec, MatchSpecUrlError, Matches, NamelessMatchSpec,
 };
+pub use minimal_prefix_record::{
+    collect_minimal_prefix_records, MinimalPrefixCollection, MinimalPrefixRecord,
+};
 pub use no_arch_type::{NoArchKind, NoArchType, RawNoArchType};
 pub use package_name::{InvalidPackageNameError, PackageName};
 pub use parse_mode::ParseStrictness;
 pub use platform::{Arch, ParseArchError, ParsePlatformError, Platform};
 pub use prefix_record::PrefixRecord;
+pub use record_traits::HasArtifactIdentificationRefs;
 pub use repo_data::{
     compute_package_url,
     patches::{PackageRecordPatch, PatchInstructions, RepoDataPatch},
