@@ -1,6 +1,8 @@
+//! This module contains utility functions for url and serde
+
 pub(crate) mod path;
 pub(crate) mod serde;
 pub(crate) mod url;
-pub(crate) mod url_with_trailing_slash;
+pub mod url_with_trailing_slash;
 
 pub(crate) use url_with_trailing_slash::UrlWithTrailingSlash;
